@@ -1,6 +1,4 @@
 from __future__ import absolute_import
-import errno
-import select
 import logging
 
 import pika
@@ -14,7 +12,7 @@ from kuyruk.worker import Worker
 from kuyruk.events import EventMixin
 from kuyruk.connection import Connection
 
-__version__ = '1.2.1'
+__version__ = '1.2.3'
 __all__ = ['Kuyruk', 'Task', 'Worker']
 
 
@@ -30,19 +28,6 @@ logger.addHandler(null_handler)
 logging.getLogger('pika').addHandler(null_handler)
 
 
-# Monkey patch ReadPoller until pika 0.9.14 is released
-def ready(self):
-    while True:
-        try:
-            return original_method(self)
-        except select.error as e:
-            if e[0] != errno.EINTR:
-                raise
-from pika.adapters.blocking_connection import ReadPoller
-original_method = ReadPoller.ready
-ReadPoller.ready = ready
-
-
 class Kuyruk(EventMixin):
     """
     Main class for Kuyruk distributed task queue. It holds the configuration
