@@ -13,6 +13,7 @@ from kuyruk.master import Master
 from kuyruk.config import Config
 from kuyruk.requeue import Requeuer
 from kuyruk.manager import Manager
+from kuyruk.scheduler import Scheduler
 
 
 logger = logging.getLogger(__name__)
@@ -39,6 +40,11 @@ def run_manager(kuyruk, args):
     m.run()
 
 
+def run_scheduler(kuyruk, args):
+    s = Scheduler(kuyruk)
+    s.run()
+
+
 def main():
     parser = argparse.ArgumentParser(conflict_handler='resolve')
 
@@ -59,7 +65,7 @@ def main():
         '-q', '--queue', default='kuyruk', help='consume tasks from')
 
     # Parser for the "master" sub-command
-    parser_master = subparsers.add_parser('master', help='run a master')
+    parser_master = subparsers.add_parser('master', help='run master')
     parser_master.set_defaults(func=run_master)
     parser_master.add_argument(
         '-q', '--queues', help='comma seperated list of queues')
@@ -73,6 +79,10 @@ def main():
     parser_master = subparsers.add_parser('manager', help='run manager')
     parser_master.set_defaults(func=run_manager)
 
+    # Parser for the "scheduler" sub-command
+    parser_scheduler = subparsers.add_parser('scheduler', help='run scheduler')
+    parser_scheduler.set_defaults(func=run_scheduler)
+
     # Parse arguments
     args = parser.parse_args()
     config = create_config(args)
