@@ -197,3 +197,8 @@ def use_session():
 def spawn_process(args=['sleep', '60']):
     import subprocess
     subprocess.check_call(args)
+
+
+@kuyruk.task(queue='scheduled')
+def scheduled(message):
+    print message
